==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Создать электронную таблицу</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Создать новую электронную таблицу</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Выровнять по нижнему краю</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Выравнять содержимое выделенных ячеек по нижнему краю</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Выровнять по центру</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Выровнять содержимое выделенных ячеек по центру</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Выровнять по левому краю</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Выровнять содержимое выделенных ячеек по левому краю</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Выровнять по правому краю</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Выровнять содержимое выделенных ячеек по правому краю</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Выровнять по верхнему краю</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Выровнять содержимое выделенных ячеек по верхнему краю</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Выровнять центры по вертикали</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Выровнять содержимое выбранных ячеек вертикально по центру</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Экспорт электронной таблицы</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Экспорт электронной таблицы в CSV-файл</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Импорт электронной таблицы</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Импорт CSV-файла в таблицу</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Объединить ячейки</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Объединение выделенных ячеек в электронной таблице</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Установить имя</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Установить имя для выбранной ячейки</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Разделить ячейку</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Разделить ранее объединенные ячейки в электронной таблице</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Полужирный текст</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Задать полужирный текст в выбранных ячейках</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Курсивный текст</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Установить курсивный текст в выбранных ячейках</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Подчеркивание текста</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Задать подчеркивание текста в выбранных ячейках</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Дополнительно</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Свойства ячеек</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Цвет</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Текст</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Фон</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Выравнивание</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>По горизонтали</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Слева</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Центр</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Справа</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>По вертикали</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Сверху</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Снизу</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Стиль</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Полужирный</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Курсив</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Подчеркивание</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Единица измерения</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Строка блока</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>&amp;Псевдоним</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Псевдоним для этой ячейки</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Всё (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Импорт файла</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Экспорт файла</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Содержимое ячейки</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Показать таблицу</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Установить цвет переднего плана ячеек</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Задает цвет переднего плана ячеек таблицы</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Установить цвет фона ячеек</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Задает цвет фона ячеек таблицы</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Чёрный</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Белый</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Красный</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Тёмно-красный</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Зеленый</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Тёмно-зелёный</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Синий</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Тёмно-синий</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Голубой</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Тёмно голубой</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Малиновый</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Тёмно-малиновый</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Жёлтый</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Тёмно-жёлтый</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Серый</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Тёмно-серый</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Светло-серый</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Дополнительно</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Форма</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Содержание</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Без имени</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Вставить строки</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Удалить строки</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Вставить столбцы</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Удалить столбцы</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Свойства...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Создать электронную таблицу</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Создать новую электронную таблицу</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Выровнять по нижнему краю</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Выравнять содержимое выделенных ячеек по нижнему краю</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Выровнять по центру</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Выровнять содержимое выделенных ячеек по центру</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Выровнять по левому краю</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Выровнять содержимое выделенных ячеек по левому краю</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Выровнять по правому краю</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Выровнять содержимое выделенных ячеек по правому краю</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Выровнять по верхнему краю</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Выровнять содержимое выделенных ячеек по верхнему краю</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Выровнять вертикально по центру</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Выровнять содержимое выбранных ячеек вертикально по центру</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Экспорт электронной таблицы</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Экспорт электронной таблицы в CSV-файл</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Импорт электронной таблицы</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Импорт CSV-файла в таблицу</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Объединить ячейки</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Объединение выделенных ячеек в электронной таблице</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Установить псевдоним</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Установить псевдоним для выбранной ячейки</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Разделить ячейку</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Разделить ранее объединенные ячейки в электронной таблице</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Полужирный текст</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Задать полужирный текст в выбранных ячейках</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Курсивный текст</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Установить курсивный текст в выбранных ячейках</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Подчеркивание текста</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Задать подчеркивание текста в выбранных ячейках</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Дополнительно</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Свойства ячеек</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Цвет</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Текст</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Фон</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Выравнивание</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>По горизонтали</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Слева</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Центр</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Справа</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>По вертикали</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Сверху</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Снизу</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Стиль</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Полужирный</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Курсив</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Подчеркивание</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Показывать Единицы измерения</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Строка единицы измерения</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>&amp;Псевдоним</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Псевдоним для этой ячейки</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Всё (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Импорт файла</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Экспорт файла</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Содержимое ячейки</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Показать таблицу</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Установить цвет переднего плана ячеек</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Задает цвет переднего плана ячеек таблицы</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Установить цвет фона ячеек</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Задает цвет фона ячеек таблицы</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Чёрный</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Белый</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Красный</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Тёмно-красный</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Зеленый</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Тёмно-зелёный</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Синий</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Тёмно-синий</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Голубой</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Тёмно-голубой</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Малиновый</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Тёмно-малиновый</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Жёлтый</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Тёмно-жёлтый</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Серый</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Тёмно-серый</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Светло-серый</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Дополнительно</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Форма</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Содержание</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Безымянный</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Вставить строки</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Удалить строки</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Вставить столбцы</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Удалить столбцы</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Свойства...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Электронная таблица</translation>
    </message>
  </context>
</TS>
